# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.custom_aggregations_v1_api import CustomAggregationsV1Api


class TestCustomAggregationsV1Api(unittest.TestCase):
    """CustomAggregationsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomAggregationsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_custom_aggregation(self) -> None:
        """Test case for delete_custom_aggregation

        Delete Custom Aggregation.
        """
        pass

    def test_get_custom_aggregation(self) -> None:
        """Test case for get_custom_aggregation

        Get Custom Aggregation By Id.
        """
        pass

    def test_get_custom_aggregations_for_workspace(self) -> None:
        """Test case for get_custom_aggregations_for_workspace

        Get Custom Aggregation.
        """
        pass

    def test_patch_custom_aggregation(self) -> None:
        """Test case for patch_custom_aggregation

        Patch Custom Aggregation
        """
        pass

    def test_post_custom_aggregation(self) -> None:
        """Test case for post_custom_aggregation

        Post Custom Aggregation.
        """
        pass

    def test_put_custom_aggregation(self) -> None:
        """Test case for put_custom_aggregation

        Update Custom Aggregation By Id.
        """
        pass

    def test_validate_custom_aggregation(self) -> None:
        """Test case for validate_custom_aggregation

        Validate A Custom Aggregation Before Creation.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.feature_flags_v1_api import FeatureFlagsV1Api


class TestFeatureFlagsV1Api(unittest.TestCase):
    """FeatureFlagsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = FeatureFlagsV1Api()

    def tearDown(self) -> None:
        pass

    def test_get_feature_flags(self) -> None:
        """Test case for get_feature_flags

        Get Feature Flags.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DType(str, Enum):
    """
    DType
    """

    """
    allowed enum values
    """
    UNDEFINED = 'undefined'
    INT = 'int'
    FLOAT = 'float'
    BOOL = 'bool'
    STR = 'str'
    UUID = 'uuid'
    TIMESTAMP = 'timestamp'
    DATE = 'date'
    JSON = 'json'
    IMAGE = 'image'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.config import Config

class TestConfig(unittest.TestCase):
    """Config unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Config:
        """Test Config
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Config`
        """
        model = Config()
        if include_optional:
            return Config(
                keywords = [
                    ''
                    ],
                regex_patterns = [
                    ''
                    ],
                examples = [
                    {example=John has O negative blood group, result=true}
                    ],
                hint = '',
                threshold = 1.337,
                disabled_pii_entities = [
                    ''
                    ],
                confidence_threshold = 1.337,
                allow_list = [
                    ''
                    ]
            )
        else:
            return Config(
                keywords = [
                    ''
                    ],
                regex_patterns = [
                    ''
                    ],
                examples = [
                    {example=John has O negative blood group, result=true}
                    ],
        )
        """

    def testConfig(self):
        """Test Config"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
